@@ -1,10 +1,10 @@
-__version__ = "0.1.15"
+__version__ = "0.1.16"
 __git_commiter_name__ = "Arnon Yaari"
-__git_commiter_email__ = "wiggin15@yahoo.com"
+__git_commiter_email__ = "arnony@infinidat.com"
 __git_branch__ = '(Not currently on any branch)'
 __git_remote_tracking_branch__ = '(No remote tracking)'
 __git_remote_url__ = '(Not remote tracking)'
-__git_head_hash__ = 'f76911e589c803acafd17ec2e1d8cacf75e19ad5'
-__git_head_subject__ = 'empty commit after version v0.1.14'
+__git_head_hash__ = '46c690bd962630f8c1212a5ea00bc379cec925d2'
+__git_head_subject__ = 'Finished release v0.1.16.'
 __git_head_message__ = ''
 __git_dirty_diff__ = ''
\ No newline at end of file
